@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,14 +12,14 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check that 'stamp-vti' is automatically distributed when info_TEXINFOS
 # and version.texi are involved.
 # Related to automake bug#7819.
 
 required=makeinfo
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << END
 AC_OUTPUT
