@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2007-2013 Free Software Foundation, Inc.
+# Copyright (C) 2007-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check EXEEXT extension for XFAIL_TESTS.
 
@@ -32,9 +32,8 @@ check_PROGRAMS = a c d
 check_SCRIPTS = b
 EXTRA_DIST = $(check_SCRIPTS)
 
-.PHONY: print-xfail-tests
-print-xfail-tests:
-	@echo BEG: $(XFAIL_TESTS) :END
+expect-xfail-tests:
+	is $(XFAIL_TESTS) == a$(EXEEXT) b c$(EXEEXT) d$(EXEEXT)
 END
 
 cat > b <<'END'
@@ -60,8 +59,8 @@ $AUTOMAKE -a
 
 ./configure
 $MAKE check
-run_make -O EXEEXT=.bin print-xfail-tests
-$FGREP 'BEG: a.bin b c.bin d.bin :END' stdout
+run_make expect-xfail-tests
+run_make expect-xfail-tests EXEEXT=.bin
 
 $MAKE distcheck
 
