@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2013 Free Software Foundation, Inc.
+# Copyright (C) 2013-2018 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Check that $(am__is_gnu_make) can be used to correctly determine if
 # we are running under GNU make.
@@ -52,8 +52,7 @@ fi
 
 rm -f ok ko
 
-$MAKE -s file >output 2>&1
-cat output
+run_make -M -- -s file
 if using_gmake; then
  test -f ok
  test ! -e ko
